@@ -13,16 +13,21 @@ class FilteringMixin(TransformMixin, AccessControlMixin, InspectionMixin):
 
     Operators:
 
-    - `!`   Not
-    - `>=`  Greater than or Equal
-    - `<=`  Less than or Equal
-    - `>`   Greater than
-    - `<`   Less than
-    - `%~`  Case insensitive Like
-    - `%`   Like
-    - `^`   In, e.g: ^1,2,3
-    - `!^`  Not In, e.g: !^1,2,3
-    - `~`   Between, e.g: ~2018-05-29T11:23:16+04:30,2018-07-30T11:23:16+04:30
+    - `=`      Exact string compare, escape the operators described below.
+    - `!`      Not
+    - `null`   Is null
+    - `!null`  Is not null
+    - `true`   Is True
+    - `false`  Is False
+    - `>=`     Greater than or Equal
+    - `<=`     Less than or Equal
+    - `>`      Greater than
+    - `<`      Less than
+    - `%~`     Case insensitive Like
+    - `%`      Like
+    - `^`      In, e.g: ^1,2,3
+    - `!^`     Not In, e.g: !^1,2,3
+    - `~`      Between, e.g: ~2018-05-29T11:23:16+04:30,2018-07-30T11:23:16+04:30
 
     Note: Without any operator means to Equal with keyword.
     Note: `LIKE` is case-insensitive by default in Sqlite
@@ -34,7 +39,7 @@ class FilteringMixin(TransformMixin, AccessControlMixin, InspectionMixin):
 
     where `age` is between `1` and `18`
     dict(age='~1,18')
-    """
+    """  # noqa: E501
 
     @classmethod
     def filter_by_dict(cls, query: Query, criteria: dict) -> Query:
@@ -62,7 +67,10 @@ class FilteringMixin(TransformMixin, AccessControlMixin, InspectionMixin):
         if not isinstance(value, str):
             raise InvalidParamError
 
-        if value.startswith("^") or value.startswith("!^"):
+        if value.startswith("="):
+            expression = column == import_value(column, value[1:])
+
+        elif value.startswith("^") or value.startswith("!^"):
             value = value.split(",")
             not_ = value[0].startswith("!^")
             first_item = value[0][2 if not_ else 1 :]
@@ -83,6 +91,10 @@ class FilteringMixin(TransformMixin, AccessControlMixin, InspectionMixin):
             expression = column.is_(None)
         elif value == "!null":
             expression = column.isnot(None)
+        elif value == "true":
+            expression = column.is_(True)
+        elif value == "false":
+            expression = column.is_(False)
         elif value.startswith("!"):
             expression = column != import_value(column, value[1:])
         elif value.startswith(">="):
